@@ -10,6 +10,7 @@ import os
 import warnings
 from os.path import join
 
+import h5py
 import numpy as np
 from astropy import units as u, wcs
 from astropy.config import get_cache_dir
@@ -20,8 +21,8 @@ from . import conf
 from . import io
 from . import snfitio
 from .bandpasses import (
-    Bandpass, BandpassInterpolator,
-    _BANDPASSES, _BANDPASS_INTERPOLATORS, read_bandpass)
+    Bandpass, _BANDPASSES, _BANDPASS_INTERPOLATORS, read_bandpass,
+    BandpassInterpolator, GeneralBandpassInterpolator, Transforms)
 
 from .constants import BANDPASS_TRIM_LEVEL
 from .magsystems import (
@@ -575,6 +576,189 @@ for letter in ('u', 'g', 'r', 'i', 'z', 'y'):
                                             load_megacampsf, args=(letter,),
                                             meta=megacam_meta)
 
+
+def load_general_bandpass_interpolator(relpath, band, name=None, version=None):
+    """Extract variable bandpass information from an HDF5 file.
+
+    Return an instance of GeneralBandpassInterpolator created from the HDF5
+    file located at `DATADIR / relpath` for a given `band`.
+
+    """
+    filename = DATADIR.abspath(relpath)
+
+    with h5py.File(filename, 'r') as f:
+        static = f['static']
+        static_transmissions = [static[k][...] for k in static]
+
+        if 'qe' in f:
+            specific_sensor_qe = {
+                int(k): v[...] for k, v in f['/qe/map'].items()}
+        else:
+            specific_sensor_qe = None
+
+        to_focalplane = {
+            int(k): v[...] for k, v in f['/transforms/to_focalplane'].items()}
+
+        to_filter = {
+            int(k): v[...] for k, v in f['/transforms/to_filter'].items()}
+
+        transforms = Transforms(to_focalplane, to_filter)
+
+        g = f['bandpasses'][band]
+        if 'radii' in g:
+            variable_transmission = (
+                g['radii'][...],
+                g['wave'][...],
+                g['trans'][...])
+        elif 'X' in g and 'Y' in g:
+            variable_transmission = (
+                g['X'][...],
+                g['Y'][...],
+                g['wave'][...],
+                g['trans'][...])
+        else:  # pragma: no cover
+            raise ValueError(
+                'failed to load interpolator from {} for band {}'.format(
+                    relpath, band))
+
+        return GeneralBandpassInterpolator(
+            static_transmissions=static_transmissions,
+            specific_sensor_qe=specific_sensor_qe,
+            variable_transmission=variable_transmission,
+            transforms=transforms,
+            name=name)
+
+
+def load_default_bandpasses(relpath, band, name=None, version=None):
+    """Extract the static (averaged) bandpass information from an HDF5 file.
+
+    Return an instance of Bandpass created from the HDF5 file located at
+    `DATADIR / relpath` for a given `band`.
+
+    """
+    filename = DATADIR.abspath(relpath)
+
+    with h5py.File(filename, 'r') as f:
+        bandpass = f['averaged_bandpasses'][band]
+        return Bandpass(
+            bandpass['wave'][...],
+            bandpass['trans'][...],
+            name=name)
+
+
+# ZTF variable bandpasses
+ztfv_meta = {
+    'filterset': 'ztf',
+    'retrieved': '22 December 2023',
+    'description': (
+        'A re-determination of the ZTF filters by P. Rosnet et al '
+        '(ZTF-II IN2P3 participation group)')}
+for version in ('0',):
+    for band in ('g', 'r', 'I'):
+        name = 'ztf::' + band
+        relpath = 'bandpasses/ztf/ztf_v{}.hdf5'.format(version)
+        _BANDPASS_INTERPOLATORS.register_loader(
+            name,
+            load_general_bandpass_interpolator,
+            args=(relpath, band),
+            version=version,
+            meta=ztfv_meta)
+
+
+# ZTF default bandpasses
+ztfd_meta = {
+    'filterset': 'ztf',
+    'retrieved': '22 December 2023',
+    'description': (
+        'A re-determination of the ZTF filters by P. Rosnet et al '
+        '(ZTF-II IN2P3 participation group) - focal plane average')}
+for version in ('0',):
+    for band in ('g', 'r', 'I'):
+        name = 'ztf::' + band
+        relpath = 'bandpasses/ztf/ztf_v{}.hdf5'.format(version)
+        _BANDPASSES.register_loader(
+            name,
+            load_default_bandpasses,
+            args=(relpath, band),
+            version=version,
+            meta=ztfd_meta)
+
+
+# megacam6 (re-measurements of the decommissioned MegaCam filters @ LMA)
+megacamv_meta = {
+    'filterset': 'megacam6',
+    'retrieved': '22 December 2023',
+    'description': (
+        'A re-determination of the decommissioned MegaCam '
+        'filters by M. Betoule and LMA')}
+for version in ('0',):
+    for band in ('g', 'r', 'i', 'i2', 'z'):
+        name = 'megacam6::' + band
+        relpath = 'bandpasses/megacam/megacam6_v{}.hdf5'.format(version)
+        _BANDPASS_INTERPOLATORS.register_loader(
+            name,
+            load_general_bandpass_interpolator,
+            args=(relpath, band),
+            version=version,
+            meta=megacamv_meta)
+
+
+# megacam6 default bandpasses
+megacamd_meta = {
+    'filterset': 'megacam6',
+    'retrieved': '22 December 2023',
+    'description': (
+        'A re-determination of the decommissioned MegaCam '
+        'filters by M. Betoule and LMA -- focal plane average')}
+for version in ('0',):
+    for band in ('g', 'r', 'i', 'i2', 'z'):
+        name = 'megacam6::' + band
+        relpath = 'bandpasses/megacam/megacam6_v{}.hdf5'.format(version)
+        _BANDPASSES.register_loader(
+            name,
+            load_default_bandpasses,
+            args=(relpath, band),
+            version=version,
+            meta=megacamd_meta)
+
+
+# HSC - Tanaki  version
+hscv_meta = {
+    'filterset': 'hsc',
+    'retrieved': '22 December 2023',
+    'description': (
+        'A model of the HSC filters - '
+        'built on a series of measurements by et al.')}
+for version in ('0',):
+    for band in ('g', 'r', 'r2', 'i', 'i2', 'z', 'Y'):
+        name = 'hsc::' + band
+        relpath = 'bandpasses/hsc/hsc_v{}.hdf5'.format(version)
+        _BANDPASS_INTERPOLATORS.register_loader(
+            name,
+            load_general_bandpass_interpolator,
+            args=(relpath, band),
+            version=version,
+            meta=hscv_meta)
+
+
+hscd_meta = {
+    'filterset': 'hsc',
+    'retrieved': '22 December 2023',
+    'description': (
+        'A model of the HSC filters - '
+        'built on a series of measurements by et al. -- '
+        'focal plane average')}
+for version in ('0',):
+    for band in ('g', 'r', 'r2', 'i', 'i2', 'z', 'Y'):
+        name = 'hsc::' + band
+        relpath = 'bandpasses/hsc/hsc_v{}.hdf5'.format(version)
+        _BANDPASSES.register_loader(
+            name,
+            load_default_bandpasses,
+            args=(relpath, band),
+            version=version,
+            meta=hscd_meta)
+
 ultrasat_meta = {'filterset': 'ultrasat'}
 
 
@@ -599,6 +783,7 @@ _BANDPASS_INTERPOLATORS.register_loader('ultrasat',
                                         load_ultrasat,
                                         meta=ultrasat_meta)
 
+
 # =============================================================================
 # Sources
 
