@@ -396,11 +396,7 @@ def _run_iminuit(chisq, parameter_names, start_values, start_errors, bounds,
 
     # The iminuit API changed significantly in version 2. Handle both the new
     # and old APIs.
-    try:
-        from distutils.version import LooseVersion
-    except ModuleNotFoundError:
-        # distutils was dropped in python 2.12
-        from looseversion import LooseVersion
+    from looseversion import LooseVersion
     iminuit_version = LooseVersion(iminuit.__version__)
 
     if verbose:
@@ -425,7 +421,6 @@ def _run_iminuit(chisq, parameter_names, start_values, start_errors, bounds,
 
         for key in fixed_parameters:
             m.fixed[key] = True
-            m.errors[key] = 0.
 
         m.migrad(ncall=maxcall)
         fmin = m.fmin
